local function isRu()
	if (GetLocale() == "ruRU") then return true end
	return false
end

local function helpMessage()
	if (isRu) then
		print("Аддон Tiny Artifact Info:")
		print("Команды /art /арт для информации об артефакте")
		print("Команды /скор /speed для информации о текущей скорости")
		print("Команды /hidespeed /showspeed для выключения и включения отображения скорости")
		print("Команды /artreset /артсброс для сброса переменных текущего персонажа")
		print("Информация об артефактах обновляется при смене специализации")
	else
		print("Tiny Artifact Info help:")
		print("Use /art for artifact info")
		print("Use /speed for current speed info")
		print("Use /hidespeed /showspeed for turning off and on speed frame")
		print("Use /artreset to reset current user variables")
		print("Artifact data is refreshed when you change specialization")
	end
end
helpMessage()

local frame = CreateFrame("FRAME");
frame:RegisterEvent("PLAYER_SPECIALIZATION_CHANGED")
frame:RegisterEvent("UNIT_INVENTORY_CHANGED")
frame:RegisterEvent("PLAYER_LOGIN")
frame:RegisterEvent("ARTIFACT_UPDATE")

if (not artifact_level) then artifact_level = nil end
if (not artifact_mult) then  artifact_mult = nil end
if (not artifact_info) then  artifact_info = {} end
if (not show_speed) then  show_speed = true end


local function translateRelicType(type)
	if (isRu) then
		if (type  == 'Wind') then return 'Буря' end
		if (type  == 'Iron') then return 'Железо' end
		if (type  == 'Life') then return 'Жизнь' end
		if (type  == 'Frost') then return 'Лед' end
		if (type  == 'Fire') then return 'Огонь' end
		if (type  == 'Shadow') then return 'Тьма' end
		if (type  == 'Light') then return 'Свет' end
		if (type  == 'Blood') then return 'Кровь' end
		if (type  == 'Fel') then return 'Скверна' end
		if (type  == 'Arcane') then return 'Тайная магия' end
	end
	return type
end

local function getItemIdFromLink(link)
	if (not link) then return end
	local itemID
	itemID = link:match("item:(%d+):")
	return itemID
end

local function gatherArtifactData()
	local artId, altArtID, name, iconFileDataID, powerAvailable, ranksPurchased, ranksKnowledge, artifactAppearanceID, appearanceModID, itemAppearanceID, altItemAppearanceID, altOnTop = C_ArtifactUI.GetEquippedArtifactInfo()
	if (artId) then
		artifact_info[artId] = {}
		artifact_info[artId]['id'] = artId
		artifact_info[artId]['name'] = tostring(name)
		artifact_info[artId]['level'] = tostring(ranksPurchased)
		artifact_info[artId]['power'] = tostring(powerAvailable)
		artifact_level = tostring(ranksKnowledge)
		for i = 1, 3 do 
			local a, b, c, d = C_ArtifactUI.GetEquippedArtifactRelicInfo(i)
			if (d) then
				local itemId = getItemIdFromLink(d)
				local e,f,g,h = C_ArtifactUI.GetRelicInfoByItemID(itemId)
				artifact_info[artId]['relic' .. tostring(i)] = {}
				artifact_info[artId]['relic' .. tostring(i)]['type'] = tostring(translateRelicType(g))
				artifact_info[artId]['relic' .. tostring(i)]['link'] = tostring(d)
				artifact_info[artId]['relic' .. tostring(i)]['level'] = tostring(C_ArtifactUI.GetItemLevelIncreaseProvidedByRelic(d))
			end
		end
	end
	local mult = C_ArtifactUI.GetArtifactKnowledgeMultiplier()
	if (mult) then artifact_mult = tostring(mult) end
end

local function gatherArtDataWhenOpened()
	if (not ArtifactFrame) then return end
	if ArtifactFrame:IsVisible() then 
		gatherArtifactData()
	end
end

SLASH_ARTINFO1 = '/art';
SLASH_ARTINFO2 = '/арт';
SLASH_CURRENTSPEED1 = '/speed';
SLASH_CURRENTSPEED2 = '/скор';
SLASH_CURRENTSPEEDHIDE1 = '/hidespeed';
SLASH_CURRENTSPEEDSHOW1 = '/showspeed';
SLASH_ARTRESET1 = '/artreset';
SLASH_ARTRESET2 = '/артсброс';
SLASH_TINYADDONINFO1 = '/tai';
SLASH_TINYADDONINFO2 = '/tinyart';
SLASH_TINYADDONINFO3 = '/tinyartinfo';
SLASH_TINYADDONINFO4 = '/tinyartifactinfo';
SLASH_TINYADDONINFO5 = '/artifactinfo';
SLASH_TINYADDONINFO6 = '/artinfo';

local function artifactInfo(msg, editbox)
	gatherArtifactData()
	print("======TINY ARTIFACT INFO======")
	if (artifact_level == nil) then
		print("No data about artifact knowledge")
	else 
		if (isRu) then
			print("Множитель знания артефакта " .. tostring(artifact_mult))
		else
			print("Artifact knowledge multiplier " .. tostring(artifact_mult))
		end
	end
	if (artifact_info == {}) then
		print("No data about artifact")
	else 
		for i,artInfo in pairs(artifact_info) do
		  local ilvl = 750
		  if (artInfo.relic1) then  ilvl = ilvl + tonumber(artInfo.relic1.level) end
		  if (artInfo.relic2) then  ilvl = ilvl + tonumber(artInfo.relic2.level) end
		  if (artInfo.relic3) then  ilvl = ilvl + tonumber(artInfo.relic3.level) end

		  if (isRu) then
	      	print(artInfo.name .. " (" .. ilvl .. ", " .. artInfo.level .. " ур, " .. artInfo.power .." силы)")
	  	  else
	      	print(artInfo.name .. " (" .. ilvl .. ", " .. artInfo.level .. " lvl, " .. artInfo.power .." power)")
	      end
	      if (artInfo.relic1) then print("   " .. artInfo.relic1.level .." - " .. artInfo.relic1.type .." - " .. artInfo.relic1.link) end
	      if (artInfo.relic2) then print("   " .. artInfo.relic2.level .." - " .. artInfo.relic2.type .." - " .. artInfo.relic2.link) end
	      if (artInfo.relic3) then print("   " .. artInfo.relic3.level .." - " .. artInfo.relic3.type .." - " .. artInfo.relic3.link) end
	    end
	end
end

local function eventHandler(self, event)
 	if (event == "PLAYER_SPECIALIZATION_CHANGED") then
 		gatherArtifactData()
 	else
 		gatherArtDataWhenOpened()
 	end
end

frame:SetScript("OnEvent", eventHandler);

--speed

local function getCurrentSpeed()
	local s,_,_,_ = GetUnitSpeed('player')
	if (s) then
		s=(s/BASE_MOVEMENT_SPEED*100)
		s=(("%%.%df"):format(0)):format(s)
	else
		s = 0
	end
	return s
end
local function printCurrentSpeed(msg, editbox)
	local s = getCurrentSpeed()
	if (isRu) then
		print('Текущая скорость:  '..s..'%')
	else
		print('Current speed:  '..s..'%')
	end
end
local function currentSpeedShow(msg, editbox)
	show_speed = true
	if (Speed) then Speed:Show() end
end
local function currentSpeedHide(msg, editbox)
	show_speed = hide
	if (Speed) then Speed:Hide() end
end

local function artVariablesReset(msg, editbox)
	artifact_level = nil
	artifact_mult = nil
	artifact_info = {}
	show_speed = true
end
local function showHelp(msg, editbox)
	helpMessage()
end

function testSpeed()
	if (Speed) then 
		if (show_speed) then
			Speed:SetText(getCurrentSpeed() .. "%")
		else
			Speed:SetText("")
		end
	end
end

SlashCmdList["ARTINFO"] = artifactInfo;
SlashCmdList["CURRENTSPEED"] = printCurrentSpeed;
SlashCmdList["CURRENTSPEEDSHOW"] = currentSpeedShow;
SlashCmdList["CURRENTSPEEDHIDE"] = currentSpeedHide;
SlashCmdList["ARTRESET"] = artVariablesReset;
SlashCmdList["TINYADDONINFO"] = showHelp;